@@ -4,10 +4,19 @@ from __future__ import unicode_literals
 from django import template
 from django.template.defaultfilters import stringfilter
 
+try:
+    from django_jinja import library
+except ImportError:
+    library = None
+
 from ..utils import create_thumbs as _create_thumbs
 
 
-register = template.Library()
+# if django_jinja not installed - then use standart template
+if library is None:
+    register = template.Library()
+else:
+    register = library
 
 
 @register.filter
